@@ -1,7 +1,7 @@
 """
 Type annotations for route53-recovery-cluster service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_cluster/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_cluster/type_defs/)
 
 Usage::
 
@@ -12,7 +12,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, Sequence
+from typing import Dict, Sequence
 
 from .literals import RoutingControlStateType
 
@@ -53,7 +53,7 @@ ResponseMetadataTypeDef = TypedDict(
         "RequestId": str,
         "HostId": str,
         "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
+        "HTTPHeaders": Dict[str, str],
         "RetryAttempts": int,
     },
 )
